import { Component, Injectable } from '@angular/core';
import {
	NgbDateStruct,
	NgbCalendar,
	NgbDatepickerI18n,
	NgbCalendarBuddhist,
	NgbDatepickerModule,
} from '@ng-bootstrap/ng-bootstrap';
import localeThai from '@angular/common/locales/th';
import {
	getLocaleDayNames,
	FormStyle,
	TranslationWidth,
	getLocaleMonthNames,
	formatDate,
	registerLocaleData,
	JsonPipe,
} from '@angular/common';
import { FormsModule } from '@angular/forms';

@Injectable()
export class NgbDatepickerI18nBuddhist extends NgbDatepickerI18n {
	private _locale = 'th';
	private _weekdaysShort: readonly string[];
	private _monthsShort: readonly string[];
	private _monthsFull: readonly string[];

	constructor() {
		super();

		registerLocaleData(localeThai);

		const weekdaysStartingOnSunday = getLocaleDayNames(this._locale, FormStyle.Standalone, TranslationWidth.Short);
		this._weekdaysShort = weekdaysStartingOnSunday.map((day, index) => weekdaysStartingOnSunday[(index + 1) % 7]);

		this._monthsShort = getLocaleMonthNames(this._locale, FormStyle.Standalone, TranslationWidth.Abbreviated);
		this._monthsFull = getLocaleMonthNames(this._locale, FormStyle.Standalone, TranslationWidth.Wide);
	}

	getMonthShortName(month: number): string {
		return this._monthsShort[month - 1] || '';
	}

	getMonthFullName(month: number): string {
		return this._monthsFull[month - 1] || '';
	}

	getWeekdayLabel(weekday: number) {
		return this._weekdaysShort[weekday - 1] || '';
	}

	getDayAriaLabel(date: NgbDateStruct): string {
		const jsDate = new Date(date.year, date.month - 1, date.day);
		return formatDate(jsDate, 'fullDate', this._locale);
	}

	getYearNumerals(year: number): string {
		return String(year);
	}
}

@Component({
	selector: 'ngbd-datepicker-buddhist',
	standalone: true,
	imports: [NgbDatepickerModule, FormsModule, JsonPipe],
	templateUrl: './datepicker-buddhist.html',
	providers: [
		{ provide: NgbCalendar, useClass: NgbCalendarBuddhist },
		{ provide: NgbDatepickerI18n, useClass: NgbDatepickerI18nBuddhist },
	],
})
export class NgbdDatepickerBuddhist {
	model: NgbDateStruct;
	date: { year: number; month: number };

	constructor(private calendar: NgbCalendar) {}

	selectToday() {
		this.model = this.calendar.getToday();
	}
}
